:: MChoice.bat version 0.0
    @goto :MChoice
::MChoice [ChoiceFileValue] [ChosenStringName] [HelpValue]
::     -- SelectionFileValue [in,req]  - file name for menu selection items list
::     -- ChosenStringName   [out,opt] - name of variable for saving selection
::                                       optional, but strongly recommended
::     -- HelpValue          [in,opt]  - Various help options starting with "/"
::                                       keyword formats: [/?[?|V|S][?]]
::     -- NOTE: lack of arguments will display a brief syntax help.
::
::Dependencies: Cmdwiz.exe by misol101
::              "Advanced Batch features via auxiliary .exe programs" by Aacini
::
::Acknowledge: DOStips forums, in general, refer to dependencies above and
::             Help formats modeled after JREPL.BAT by Dave Benham, originally
::             posted at http://www.dostips.com/forum/viewtopic.php?f=3&t=6044
::
::MChoice.bat version 0.0 by John Andrejsons
::
::  Release History:
::    2016-11-17 v0.0: Initial release to DOStips forum
::
:: Bugs can be reported and suggestions are welcomed in thread:
::
::  Post subject: Mouse-Selectable Menu from a data file - a/la CHOICE
::  http://www.dostips.com/forum/viewtopic.php?p=50143#p50143
::  Posted: Thu Nov 17, 2016 1:58 am by theFeDuke
::
::============ Documentation ===========
::
:::
:::  Present the contents of a file as a menu of lines selectable by mouse
:::
:::MChoice [ChoiceFileValue] [ChosenStringName] [HelpValue]
:::
::
::============ Formal Documentation continues at end of batch script ===========
::

:MChoice [/?[/?HelpOption] | ChoiceFileValue[In,Req] ChosenStringName[Out,Opt]

@Echo Off&SetLocal EnableDelayedExpansion
::  Capture the first line of this script expecting the name and version number
    set /p "MouseVer="<"%~fs0"

::  Check if help is requested. This technique is based on:
::
::  Post subject: Re: Passing batch argument to Choice command
::  Posted: Sun Apr 24, 2016 11:39 am by Aacini
::  http://www.dostips.com/forum/viewtopic.php?p=46412#p46412
Set "vars=arg1=%~1,arg2=%~2,arg3=%~3,arg4=%~4,arg5=%~5,arg6=%~6,arg7=%~7,arg8=%~8,arg9=%~9"
Set "%vars:,=" & set "%"

::  If /I "%arg1%" EQU "" Set "arg1=/?S"
For /L %%I In (1 1 9) do (
    set "arg=!arg%%I!"
Rem.In this particular example the rightmost argument takes effect.
    If /I "!arg!" EQU "/?V"  (Set "HelpSw=0"&Echo()
    If /I "!arg!" EQU "/?"   (Set "HelpSw=1"&Echo()
    If /I "!arg!" EQU "/??"  (Set "HelpSw=2"&Echo()
    If /I "!arg!" EQU "/???" (Set "HelpSw=3"&Echo()
    If /I "!arg!" EQU "/?S"  (Set "HelpSw=4"&Echo()
)

::
:: Code to show various types of Help begins here.
If /I "%HelpSw%" EQU "0" (
    Echo.%MouseVer:~3%
    Exit /B 1
)
If /I "%HelpSw%" EQU "1" (
    For /f "tokens=* delims=:" %%A in ('findstr "^:::" "%~f0"') do @echo(%%A
    Exit /B 1
)
If /I "%HelpSw%" EQU "2" (
    Echo.
    Echo.Formal help using the 'More' filter follows:
    Echo.
    Pause & CLS
    (For /f "tokens=* delims=:" %%A in ('findstr "^:::" "%~f0"') do @echo(%%A)|more /e
    Echo.
    Exit /B 1
)
If /I "%HelpSw%" EQU "3" (
    Echo.
    Echo.Informal help using the 'More' filter follows and includes
    Echo.all comments prefaced with '::' in order of appearance.
    Echo.
    Echo.Properly formatted help is available using options:
    Echo.'/?' or '/??'
    Echo.
    Pause & CLS
    (For /f "tokens=* delims=:" %%A in ('findstr "^::" "%~f0"') do @echo(%%A)|more /e
    Echo.
    Echo.Reminder: Properly formatted help is available using options:
    Echo.'/?' or '/??'
    Exit /B 1
)
If /I "%HelpSw%" EQU "4" (
    Echo.%~n0 command syntax:
    Echo.
    For /f "tokens=* delims=:" %%A in ('findstr "^:::%~n0" "%~f0"') do @echo(%%A
    Echo.
    Echo(^(Use '%~n0 /?' to get more help.^)
    Exit /B 1
)

::
::  Assign Arg2 before :RedoScreen to accept missing ChosenStringName manually
    Set "Arg2=%~2"

::  Validate accessabity of pre-requisite executables before continuing
    >nul Verify
    Set "MaxError=%ErrorLevel%"
::  The WHERE command is not available from WinXP and is used in :CanItRun
    VER | find  " 5.1." > nul && Set "OnXP=XP"
    Call :CanItRun%OnXP% MaxError CmdWiz.exe
    If "%MaxError%" EQU "1" (Echo.
        Echo.Refer to Post subject: ^"Cmdwiz - cmd helper tools^" by misol101
        Echo.at http://www.dostips.com/forum/viewtopic.php?p=48971#p48971
        Echo.for download instructions.
    )
    Call :CanItRun%OnXP% MaxError ColorShow.exe
    Call :CanItRun%OnXP% MaxError CursorPos.exe
    Call :CanItRun%OnXP% MaxError GetInput.exe
    Call :CanItRun%OnXP% MaxError Show.exe
    Call :CanItRun%OnXP% MaxError Window.exe
    If "%MaxError%" EQU "1" (Echo.
        Echo.The above command^(s^) are required for this script to run successfully,
        Echo.and need to be in the current directory or PATH.
        Echo.
        Echo.Refer to Post subject: ^"Advanced Batch features via auxiliary .exe programs^" by Aacini
        Echo.at http://www.dostips.com/forum/viewtopic.php?p=17101#p17101
        Echo.for download instructions for any of the executables except CmdWiz.exe
        Echo.
        Echo.%MouseVer:~3% cannot continue.
        Exit /B 1
    )

::
::  Retrieve Window stats using CmdWiz command with getconsoledim operation
    CmdWiz getconsoledim w&set "ScrBuffCols=!errorlevel!"
    CmdWiz getconsoledim h&set "ScrBuffRows=!errorlevel!"
    CmdWiz getconsoledim sw&set "WindowCols=!errorlevel!"
    CmdWiz getconsoledim sh&set "WindowRows=!errorlevel!"
::  Save original window and buffer dimensions to restore window properties
    set "SaveBuffRows=%ScrBuffRows%"
    set "SaveBuffCols=%ScrBuffCols%"
    set "SaveWinRows=%WindowRows%"
    set "SaveWinCols=%WindowCols%"

::  Checkpoint for redisplay if critical Command Prompt Properties have changed.
:ReDoScreen
::  Retrieve current Window stats for :ReDoScreen changes
    CmdWiz getconsoledim w&set "ScrBuffCols=!errorlevel!"
    CmdWiz getconsoledim h&set "ScrBuffRows=!errorlevel!"
    CmdWiz getconsoledim sw&set "WindowCols=!errorlevel!"
    CmdWiz getconsoledim sh&set "WindowRows=!errorlevel!"

::
::  SECTION ONE: Display the top non-data rows and establish top row for data.
::
::  Guarantee minimum window and screen buffer sizes for a readable display.
    If %ScrBuffRows% LSS 26 (Set "ScrBuffRows=26"&Set "BufSw=1")
    If %ScrBuffCols% LSS 90 (Set "ScrBuffCols=90"&Set "BufSw=1")
    If %WindowRows% LSS 26 (Set "WindowRows=26"&Set "WinSw=1")
    If %WindowCols% LSS 78 (Set "WindowCols=78"&Set "WinSw=1")
    If "%BufSw%" EQU "1" CmdWiz SetBufferSize %ScrBuffColS% %ScrBuffRows%
    If "%WinSw%" EQU "1" Window Size %WindowColS% %WindowRows%
    Color
::  Define top of clickable area and validate arguments
    If "%Arg2%" EQU "" (
        ColorShow /0E 13 10 "Lack of 2nd argument name prevents saving any selected string value" 13 10 /
        CursorPos
Rem.    Define secondary clickable area to set missing ChosenStringName
        Set /A "ArgRow=((!errorlevel!>>16)&0xFFFF)"
    ) Else Set "ArgRow=-1"
::  Validate the file of rows from which to select a line
    If /I "%~1" EQU "" (
        ColorShow /0C 13 10 "The first argument with the choices file is missing." 13 10 /
        ColorShow /0C 13 10 "'%MouseVer:~3%' cannot continue. " 13 10 /
        ColorShow /07 13 10 "(Use " /0B "'%~n0 /?'" /07 " to get more help.)" 13 10 /
        ColorShow /0F 13 10 "%~n0 command syntax: " 13 10 13 10
        For /f "tokens=* delims=:" %%A in ('findstr "^:::%~n0" "%~f0"') do @echo(%%A
        ColorShow /07
Rem.    Not bothering to restore Command Prompt Properties before Exit.
        Exit /B 1
    ) Else (
        Set "SelectionFile=%~1"
        If NOT EXIST "!SelectionFile!" (
            ColorShow /0C 13 10 "The choices file '!SelectionFile!' was not found." 13 10 /
            ColorShow /0C 13 10 "'%MouseVer:~3%' cannot continue. " 13 10 /
            Exit /B 1
        )
        Set "SelectionDir=%~1"
        If /I "!SelectionDir!" NEQ "" Set "SelectionDir=!SelectionDir:.=!"
        If /I "!SelectionDir!" NEQ "" Set "SelectionDir=!SelectionDir:/=!"
        If /I "!SelectionDir!" NEQ "" Set "SelectionDir=!SelectionDir:\=!"
        If /I "!SelectionDir!" EQU "" (
            ColorShow /0C 13 10 "The choices file '!SelectionFile!' was not found." 13 10 /
            ColorShow /0C 13 10 "'%MouseVer:~3%' cannot continue. " 13 10 /
            Exit /B 1
        )
    )
    If "%Arg2%" EQU "" (
        ColorShow /E0 "Left- or Right-Click anywhere" /EC " ON this line to DEFINE " /E0 "variable name." 13 10 /
        ColorShow /0E "Any word or row selected by mouse will still be displayed on screen" 13 10 /
    )

    ColorShow /0F 13 10 "A MENU of data selectable by '%MouseVer:~3%' shows below: " 13 10 13 10 /
    ColorShow /9F "[Left- or Right-Click" /9E " ANYWHERE BELOW " /
    CursorPos
    set /A "TopRow=((%errorlevel%>>16)&0xFFFF)+1"
    ColorShow /9F "this line. Left- selects LINE]" /
::  Add some reserve space after the data lines
    Set "AllowLines=9"
    set /A "NewRow=TopRow+AllowLines"
    If %NewRow% GTR %ScrBuffRows% (
        If %TopRow% GTR 7 (Rem.Quick display fix prior to checking data lines
            CLS
            GoTo:ReDoScreen
        )
    )

::
::  SECTION TWO: Display the field of rows from which to select a line or string
::
::  Count the number of lines in file and add some reserve space
    For /F %%a in ('find /C /V "" ^< "%SelectionFile%"') do set /A "DataLines=%%a"

::  Adjust screen buffer height if necessary for usable screen pointing results
    set /A "NewRow=TopRow+DataLines+AllowLines"
    If %NewRow% GTR %ScrBuffRows% CmdWiz setbuffersize keep %NewRow%

::  Read file lines to get max line length and create interim file
    If Exist "%Temp%\%~n0_Menu.txt" Del "%Temp%\%~n0_Menu.txt"
    Set "maxLen=0"
   (for /L %%i in (1,1,!dataLines!) do (
        set "line="
        set /P "line="
        Echo.'!line!'>> "%Temp%\%~n0_Menu.txt"
        CmdWiz StringLen "!line!"
        If !ErrorLevel! GTR !maxLen! Set /A "maxLen=!ErrorLevel!+1"
    )) < "%SelectionFile%"


::  Adjust screen if necessary to accommodate larger width of displayed lines
    If %MaxLen% GTR %ScrBuffCols% CmdWiz setbuffersize %MaxLen% keep

    ColorShow /0F " !MaxLen! Wide" /
    ColorShow /07 13 10 /A0
::  Display the lines available for selection
    Type "%SelectionFile%"
    ColorShow /07

::
::  SECTION THREE: Display and interact with the bottom non-data rows
::
::  Populate bottom of clickable area fixed lines
    ColorShow /CF "[Left- or Right-Click anywhere" /CE " ON this line to QUIT " /CF "with NO choice]" 13 10 /
    ColorShow /9F "[Left- or Right-Click" /9E " ANYWHERE ABOVE " /
    ColorShow /9F "this line. Right selects WORD]" /0F " %datalines% Deep" 13 10 /
    CursorPos&Set /A "BotRow=((!errorlevel!>>16)&0xFFFF)-2, MsgRow=BotRow+6"
    ColorShow /07 13 10 "Click on " /A0 "any MENU line" /07 " or " /CF "the Quit line" /07 " to select that word or line" 13 10 /

::  Interpret moused location using AuxProgram: GetInput
:InLoop
    CursorPos 0 %MsgRow%
    GetInput
    Set /A "input=%errorlevel%"
    If %input% GTR 0 (
        CursorPos 0 -1
        If "%input%" EQU "27" (
            Set /A "CSlen=WindowCols-73"
            ColorShow / "Simulating a termination click because the '" "Esc"  "' key was pressed. " 32x!CSlen! 13 10 /07
            ColorShow / 32x%WindowCols% /
            Set "MRow=%BotRow%"
            Set "MClick=Left"
            CursorPos 0 %MsgRow%
            Goto :Escape
Rem.        Possible future use - filter numerals for multiple word selection
        ) Else (
            Set /A "CSlen=WindowCols-60"
            ColorShow / "A key, loosely interpreted as the '" %input%  "' key was pressed. " 32x!CSlen! 13 10 /07
            Set /A "MRow=BotRow+5"
            Set "MClick=None"
        )
    ) Else If %input% EQU 0 (rem.Timed out with no interation - not enabled
        Set /A "MRow=BotRow+5"
        Set "MClick=None"
    ) Else (rem.Mouse button clicked
        Set /A "input=-input, Mrow=input >> 16, Mcol=input & 0xFFFF"
        if !Mcol! LSS 32768 (
            CursorPos 0 -1
            Set /A "CSlen=WindowCols-32"
            ColorShow /07 "LEFT button click at row !MRow!" 32x!CSlen! 13 10
            Set "MClick=Left"
        ) Else (
            Set /A MCol-=32768
            CursorPos 0 -1
            Set /A "CSlen=WindowCols-31"
            ColorShow /07 "RIGHT button click at row !MRow!" 32x!CSlen! 13 10
            Set "MClick=Right"
        )
    )

::  Process valid clicks or loop back if outside area
    If %MRow% EQU %ArgRow% (Rem.Prompt for saved string name and start again.
        CursorPos 0 -2
        Set /A "CSlen=WindowCols-45"
        ColorShow /0E 13 10 "Correcting the missing second argument. Enter a name or " /CF "'Q' to Quit" /0E 32x!CSlen! 13 10
        Set /A "CSlen=WindowCols-57"
        ColorShow /0E "Enter a variable name to save the value of the selected string " 32x!CSlen! 13 10
        If "%Displayed%" EQU "1" (
            For /L %%I In (1 1 8) do ColorShow / 32x%WindowCols% 13 10 /
            ColorShow / 32x%WindowCols% 13 10 /0E
            CursorPos 0 %MsgRow%
            CursorPos 0 +1
            Set "Displayed="
        )
        Set    "Arg2="
        Set /P "Arg2=: ==> "
        CursorPos 0 -3
        If "!Arg2!" EQU "" (
            Set /A "CSlen=WindowCols-55"
            ColorShow /0E "No saved variable name entered so it remains undefined." 32x!CSlen! 13 10
        ) Else (
            If /I "!Arg2!" EQU "Q" (
                Set /A "CSlen=WindowCols-62"
                ColorShow / "Simulating a termination click because '" "Q"  "' was entered. " 32x!CSlen! 13 10 /07
                ColorShow / 32x%WindowCols% /
                Set "MRow=%BotRow%"
                Set "MClick=Left"
                Goto :Escape
            ) Else (
                Set /A "CSlen=WindowCols-40"
                ColorShow /0E "Saved variable name is now defined as !Arg2!." 32x!CSlen! 13 10
            )
        )
        Set /A "CSlen=WindowCols-51"
        ColorShow / "Row %MRow% is ABOVE the Clickable area of %TopRow%-%BotRow%" 32x!CSlen! 13 10 /
        ColorShow / 32x%WindowCols% 13 10 /
        If "%Displayed%" EQU "1" (For /L %%I In (1 1 8) do ColorShow / 32x%WindowCols% 13 10 /&Set "Displayed=")
        Goto :inloop
Rem.    CLS
Rem.    GoTo:ReDoScreen
    )
    If %MRow% LSS %TopRow% (
        Set /A "CSlen=WindowCols-51"
        ColorShow / "Row %MRow% is ABOVE the Clickable area of %TopRow%-%BotRow%" 32x!CSlen! 13 10 /
        If "%Displayed%" EQU "1" (For /L %%I In (1 1 8) do ColorShow / 32x%WindowCols% 13 10 /&Set "Displayed=")
        Goto :inloop
    )
    If %MRow% GTR %BotRow% (
        Set /A "CSlen=WindowCols-51"
        ColorShow / "Row %MRow% is BELOW the Clickable area of %TopRow%-%BotRow%" 32x!CSlen! 13 10 /
        If "%Displayed%" EQU "1" (For /L %%I In (1 1 8) do ColorShow / 32x%WindowCols% 13 10 /&Set "Displayed=")
        Goto :inloop
    )
:Escape
    If %MRow% EQU %BotRow% (
        If "%Displayed%" EQU "1" (For /L %%I In (1 1 8) do ColorShow / 32x%WindowCols% 13 10 /&Set "Displayed=")
        Set /A "CSlen=WindowCols-23"
        ColorShow /CF 13 10 "Leaving," /0C " as requested. " 32x!CSlen! 13 10 /
        If "%Displayed%" EQU "1" (For /L %%I In (1 1 8) do ColorShow / 32x%WindowCols% 13 10 /&Set "Displayed=")
Rem.    Restore window and buffer dimensions to original
        CmdWiz SetBufferSize %SaveBuffColS% %SaveBuffRows%
        Window Size %SaveWinColS% %SaveWinRows%
        Exit /B 1
    )

    If /I "%MClick%" EQU "Left" (CursorPos 0 -1&Show "Mouse Left-click at Row %MRow%, Col %MCol%" 13 10)
    If /I "%MClick%" EQU "Right" (
        CmdWiz GetCharAT %MCol% %MRow%
        If /I "!ErrorLevel!" EQU "32" (
            CursorPos 0 -1
            Set /A "CSlen=WindowCols-53"
            ColorShow / "A blank space was Right-clicked at Row %MRow%, Col %MCol%" 32x!CSlen! 13 10 /07
            Set /A "CSlen=WindowCols=54"
            ColorShow /0E "which was within the Clickable area of %TopRow%-%BotRow%" 32x!CSlen! 13 10 /0F
            If "%Displayed%" EQU "1" (For /L %%I In (1 1 8) do ColorShow / 32x%WindowCols% 13 10 /&Set "Displayed=")
            Goto :inloop
        )
    )

::
::  SECTION FOUR: Save or display a valid selection
::
::  Process the selected line
    CursorPos 0 -1&ColorShow /0E "Detected a mouse %Mclick%-click at Row %MRow%. . ." 32x22 13 10 /
    ColorShow /0E "which is within the Clickable area of %TopRow%-%BotRow%" 32x28 13 10 /0F
    If "%Arg2%" NEQ "" ColorShow /0E 13 10 "Saving value to variable '%Arg2%'." 13 10

::  Right-click selects just a word and Left-click selects the whole line
    If /I "%MClick:~,1%" EQU "R" (
        Call :GetWord "%MCol%" "%MRow%" MouseString
    ) Else (
        Set /A "Chosen=Mrow-TopRow+1"
        Set "CheckLines=0"
Rem.    The interim file is needed to handle nul or blank lines in the data.
        For /F "Delims=" %%C in ('Type "%Temp%\%~n0_Menu.txt"') do (
            Set /A "CheckLines+=1"
            If "!CheckLines!" EQU "!Chosen!" (
                Set "MouseString=%%C"
                Set "MouseString=!MouseString:~,-1!"
                Set "MouseString=!MouseString:~1!"
            )
        )
    )

::  Display a valid selection if save variable is still not defined
    If "%Arg2%" EQU "" (
        Echo.In the absence of a second argument,
        Echo.the mouse %MClick%-click did NOT save a value.
        ColorShow / 13 10 "The selected string (between " /0A "==>" / " and " /0A "<==" / ") would have been:" 13 10 /
        ColorShow /0A 13 10 "==>" /A0
        Set /P <nul =%MouseString%
        ColorShow /0A "<==" /07 32x70 13 10 /
        Set "Displayed=1"
Rem.    Here is an opportunity for another prompt to set a saved string variable
        Goto :inloop
    )

::  Restore window and buffer dimensions to original
    CmdWiz SetBufferSize %SaveBuffColS% %SaveBuffRows%
    Window Size %SaveWinColS% %SaveWinRows%
    ColorShow /07

::  Save the valid selection
(   EndLOCAL &Rem.Return the selected string
    If /I "%Arg2%" NEQ "" (
        If "%MouseString%" NEQ "" (
            SET "%Arg2%=%MouseString%"
        ) Else (
            Echo.The Selection was an empty string so the mouse
            Echo.%MClick%-click did NOT save a value for '%arg2%'.
        )
    ) Else (
        Echo.In the absence of a second argument,
        Echo.the mouse %MClick%-click did NOT save a value.
    )
)

    Exit /B 0


:GetWord col row returnstringname
    SetLocal EnableDelayedExpansion
    Set "MoCol=%~1"
    Set "MoRow=%~2"
    Set /a "LastPos=ScrBuffCols-1"

    Set /a "LastSpace-=1"
    For /L %%I in (0,1,%MoCol%) do (
        CmdWiz getcharat %%I %MoRow%
        If "!ErrorLevel!" EQU "32" (
            If %%I LSS %MoCol% (
                Set "LastSpace=%%I"
            )
        )
    )

    Set /a "LastSpace+=1"
    For /L %%I in (%LastSpace%,1,%Lastpos%) do (
        CmdWiz getcharat %%I %MoRow%
Rem.    Echo.%%I: '!ErrorLevel!'
        If "!ErrorLevel!" EQU "32" Goto :LastWord
        If "!ErrorLevel!" EQU "13" Goto :LastWord
        Set "GotChar=!GotChar! !Errorlevel!"
    )
:LastWord

    Show %GotChar%>"%Temp%\%~n0_Word.txt"
    Set /P <"%Temp%\%~n0_Word.txt" "MouseString="

(   EndLOCAL &Rem.Return the selected string
    If "%~3" NEQ "" (
        SET "%~3=%MouseString%"
    ) Else (
        Show "'" %GotChar% "' was the moused word." 13 10
    )
)

Exit /B

:CanItRun MaxError executable
::  WHERE command is not available from WinXP
    >nul 2>nul Where "%~2"
    If Errorlevel 1 (Echo.
        Set "%~1=1"
        Echo.The '%~2' command is not accessable.
    )

    Exit /B

:CanItRunXP MaxError executable
::  WHERE command is not available from WinXP - interim - add substitute later
    If NOT Exist "%~2" (
        Set "%~1=1"
        Echo.The '%~2' command is not accessable.
    )

    Exit /B

::
::============ Formal Documentation continues ===========
::
:::
:::  Positional Arguments:
:::
:::      SelectionFileValue
:::
:::          This is the name of the file that contains only the line
:::          items that are to be displayed on the screen as a menu.
:::          Normal resolution of DOS file names applies.
:::          The remainder of the screen is constructed by the script
:::          and contains status information and instructions that do not
:::          result in a menu data selection when acted on by the mouse.
:::
:::      ChosenStringName
:::
:::          This is the name of variable that if specified will
:::          be set to the character string selected from the menu
:::          by a left- or right-click of the mouse.
:::          This argument is optional, but its use is so strongly
:::          recommended, that a selectable line is added above the menu
:::          to allow its definition by prompt, if it is found to be absent.
:::
:::
:::  Optional Arguments:
:::
:::       The option names are case insensitive, and may appear in any order,
:::       freely mixed with arguments. The latest overrides duplicates.
:::
:::
:::  Help Options:
:::
:::
:::      /?
:::          This is a flag option that if specified will
:::          display the normal formatted help documentation
:::
:::      /?V
:::          This is a flag option that if specified will
:::          display the version number for MChoice.bat.
:::
:::      /??
:::          This is a flag option that if specified will
:::          display the formatted help documentation
:::          using the MORE filter for pagination.
:::
:::      /???
:::          This is a flag option that if specified will
:::          informal help using the 'More' filter and includes
:::          all comments prefaced with '::' in order of appearance.
:::
:::      /?S
:::          This is a flag option that if specified will
:::          display a brief usage description line for MChoice and is
:::          normally activated in the absence of options and arguments.
:::
:::
:::  Usage Notes:
:::
:::
:::      Usage Considerations
:::
:::          This script is primarily designed to provide a MENU application
:::        where the choice is selected by using the mouse rather then the
:::        keyboard.  Although vaguely modeled on the CHOICE command, the
:::        design removes restrictions on the number of choices available and
:::        does not require the interpretation of return codes and the
:::        associated hard-coded decisions.  The input file defines the MENU
:::        and the returned string is as it appears on the display.  These
:::        data are easily changed and can be made to require as much parsing
:::        as desired or to be self-defining, even to the point of being
:::        directly executable.  The basics do appear to work on Windows XP.
:::
:::      Re-Purposing
:::
:::          The open MENU design is very inviting to experimentation with
:::        all manner of data.  Despite the author's views about a reasonable
:::        MENU application not exceeding a few screens of data to scroll,
:::        the dynamic changes to the DOS Prompt Properties used in this script
:::        do not prevent pressing limits on line lengths and the number of
:::        input records that could be browsed.
:::
:::      Pre-requisites
:::
:::          There is guidance on sourcing the required software routines
:::      if the script determines that they are not accessible.  However,
:::      if the distribution ZIP file is extracted to a folder that is used
:::      as the current directory or added to the path, those instructions
:::      should never be displayed.
:::
:::      Status Messages
:::
:::          There is an attempt to recognise all mouse and keyboard inputs
:::      on two status lines below the menu, with appropriate action
:::      message below them.  Only the 'Esc' key is acted upon, so only
:::      the simplest attempt is made to identify the actual key, as it
:::      really does not matter other than noting the interaction.
:::
:::      Saving Results
:::
:::          The script only terminates in a controled manner if requested
:::      or if a string is selected and saved in a variable.  If the variable
:::      has not been defined,  multiple chances to do so are offered before
:::      the script ends.  This prompting feature is of limited use if the
:::      script is called from another script instead of as a native command.
:::
:::      Empty Menu Lines
:::
:::          The script supports and uses lines that are nul, empty or
:::      all spaces and uses them for display and retrieval by using an
:::      interim file to account for them and keep the rows synchronized.
:::      Right-clicking a space or empty area will display an activity
:::      message and no action is take, but a Left-click will caused the
:::      saved variable string to be SET returned as undefined.
:::
::
